import numpy as np
import matlab.engine
import os

# --------------------------------------------------- #
# MATLAB CONNECTION CLASS
# --------------------------------------------------- #
class matlab_connection :

  def __init__(self, session_name):
    self.session_name = session_name
    self.eng = matlab.engine.connect_matlab(session_name)

  def put_var(self, var_name, values) :
    self.eng.workspace[var_name] = matlab.double( np.asarray(values).tolist() ) 

  def get_var(self, var_name) :
    return np.asarray( self.eng.workspace[var_name] )

  def move_to_cwd(self) :
    f = self.eng.cd(os.getcwd())

  def run_script(self, script_name) :
    f = self.eng.script_from_python(script_name)

  def run_function(self, fcn_name, data) :
    f = self.eng.function_from_python(script_name, data)

  def should_stop(self) :
    return self.eng.should_stop()


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="matlab_connection",
    url="https://github.com/pckosek/matlab_connection",
    version="0.0.3",
    description="Package to streamline reading from and writing data to MATLAB from python",
    long_description=long_description,
    long_description_content_type="text/markdown",    
    author="Paul Kosek",    
    author_email="pckosek@fcps.edu",
    
    packages=setuptools.find_packages(),
    include_package_data=True,
    package_data={
        'matlab_functions':
             ['matlab_functions/script_from_python.m',
             'matlab_functions/function_from_python.m'
             ]
    },

    # Dependent packages (distributions)
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ], 
    keywords='MATLAB python', 

)